#ifndef _EFL_UI_TAB_PAGE_EO_H_
#define _EFL_UI_TAB_PAGE_EO_H_

#ifndef _EFL_UI_TAB_PAGE_EO_CLASS_TYPE
#define _EFL_UI_TAB_PAGE_EO_CLASS_TYPE

typedef Eo Efl_Ui_Tab_Page;

#endif

#ifndef _EFL_UI_TAB_PAGE_EO_TYPES
#define _EFL_UI_TAB_PAGE_EO_TYPES

#ifdef EFL_BETA_API_SUPPORT
typedef enum
{
  EFL_UI_TAB_PAGE_TAB_CHANGED_LABEL = 0, /**< Label changed */
  EFL_UI_TAB_PAGE_TAB_CHANGED_ICON /**< Icon changed */
} Efl_Ui_Tab_Page_Tab_Changed;
#endif /* EFL_BETA_API_SUPPORT */

#ifdef EFL_BETA_API_SUPPORT
/** Information of changed event
 *
 * @ingroup Efl_Ui
 */
typedef struct _Efl_Ui_Tab_Page_Tab_Changed_Event
{
  Efl_Ui_Tab_Page_Tab_Changed changed_info;
} Efl_Ui_Tab_Page_Tab_Changed_Event;
#endif /* EFL_BETA_API_SUPPORT */


#endif
#ifdef EFL_BETA_API_SUPPORT
/** Tab Page class
 *
 * @ingroup Efl_Ui_Tab_Page
 */
#define EFL_UI_TAB_PAGE_CLASS efl_ui_tab_page_class_get()

EWAPI const Efl_Class *efl_ui_tab_page_class_get(void);

EWAPI extern const Efl_Event_Description _EFL_UI_TAB_PAGE_EVENT_TAB_CHANGED;

/** Called when tab changed
 * @return Efl_Ui_Tab_Page_Tab_Changed_Event
 *
 * @ingroup Efl_Ui_Tab_Page
 */
#define EFL_UI_TAB_PAGE_EVENT_TAB_CHANGED (&(_EFL_UI_TAB_PAGE_EVENT_TAB_CHANGED))
#endif /* EFL_BETA_API_SUPPORT */

#endif
